"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validateAndFix = validateAndFix;

var _lodash = _interopRequireDefault(require("lodash.isplainobject"));

var _lodash2 = _interopRequireDefault(require("lodash.clonedeep"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// validates svgo opts
// to contain minimal set of plugins that will strip some stuff
// for the babylon JSX parser to work
const essentialPlugins = {
  removeDoctype: true,
  removeComments: true,
  removeStyleElement: true
}; // If not explicitly set by the user, then set this value

const pluginDefaults = {
  removeViewBox: false
};

function getPlugin(pluginLike, value = true) {
  if (typeof pluginLike === "string") {
    return [pluginLike, {
      [pluginLike]: value
    }];
  }

  const pluginName = Object.keys(pluginLike)[0];
  return [pluginName, pluginLike];
}

function validateAndFix(opts = {}) {
  if (!(0, _lodash.default)(opts)) throw new Error("Expected options.svgo to be Object.");
  let cleanOpts = (0, _lodash2.default)(opts);
  const plugins = new Map(); // add user input plugins to the map

  if (Array.isArray(cleanOpts.plugins)) {
    for (const plugin of cleanOpts.plugins) {
      const p = getPlugin(plugin);
      plugins.set(p[0], p[1]);
    }
  }

  for (let plugin in essentialPlugins) {
    if (hop(essentialPlugins, plugin)) {
      const p = getPlugin(plugin, essentialPlugins[plugin]); // overwrite

      plugins.set(p[0], p[1]);
    }
  }

  for (let plugin in pluginDefaults) {
    if (hop(pluginDefaults, plugin)) {
      const p = getPlugin(plugin, pluginDefaults[plugin]); // do not overwrite

      const existingPlugin = plugins.get(p[0]);

      if (existingPlugin == null) {
        plugins.set(p[0], p[1]);
      }
    }
  }

  cleanOpts.plugins = [];

  for (const [, plugin] of plugins) {
    cleanOpts.plugins.push(plugin);
  }

  return cleanOpts;
}

function hop(o, key) {
  return Object.prototype.hasOwnProperty.call(o, key);
}